{% load bootstrap_tags i18n %}

<nav class="navbar {{ navbar_classes }}" role="navigation">
{% block navbar %}
	{% block navbar-brand %}<a class="navbar-brand" href="/">Brand</a>{% endblock %}

	{% block navbar-toggler %}
	<button class="navbar-toggler" type="button" ng-click="toggleNavCollapse()" aria-label="{% trans 'Toggle navigation' %}">
		<span class="navbar-toggler-icon"></span>
	</button>
	{% endblock navbar-toggler %}

	{% block navbar-collapse %}
	<div class="collapse navbar-collapse" uib-collapse="!isNavCollapsed">
		<ul class="navbar-nav">
		{% block navbar-nav %}{% main_menu "bootstrap4/menu/ng-navbar.html" %}{% endblock %}
		</ul>
	</div>
	{% endblock navbar-collapse %}
{% endblock navbar %}
</nav>