{% load bootstrap_tags %}

{% block extra-styles %}{% endblock %}
{% block extra-scripts %}{% endblock %}

<nav class="navbar {{ navbar_classes }}" role="navigation">
{% block navbar %}
	{% block navbar-brand %}<a class="navbar-brand" href="/">Brand</a>{% endblock %}

	{% block navbar-toggler %}
	<button class="navbar-toggler" type="button" data-toggle="collapse" data-target="#navbarSupportedContent" aria-controls="navbarSupportedContent" aria-expanded="false" aria-label="Toggle navigation">
		<span class="navbar-toggler-icon"></span>
	</button>
	{% endblock navbar-toggler %}

	<div class="collapse navbar-collapse" id="navbarSupportedContent">
	{% block navbar-nav %}
		<ul class="navbar-nav">{% main_menu "bootstrap4/menu/navbar.html" %}</ul>
	{% endblock %}
	</div>
{% endblock navbar %}
</nav>
