{% load bootstrap_tags i18n %}
<nav class="navbar {{ navbar_classes }}" role="navigation">
{% block navbar %}
	<div class="container">
		<div class="navbar-header">
	{% block navbar-header %}
			<button type="button" class="navbar-toggle" data-toggle="collapse" data-target=".navbar-collapse">
				<span class="sr-only">{% trans "Toggle navigation" %}</span>
				<span class="icon-bar"></span>
				<span class="icon-bar"></span>
				<span class="icon-bar"></span>
			</button>
	{% endblock %}
		</div>
		<div class="collapse navbar-collapse">
	{% block navbar-nav %}
			<ul class="nav navbar-nav">{% main_menu %}</ul>
	{% endblock %}
		</div>
	</div>
{% endblock navbar %}
</nav>