{% load menu_tags %}{% spaceless %}
<div class="row">
	<div class="{{ breadcrumb_col|default:'col-xs-12' }}">
		<ol class="{{ breadcrumb_classes }}">
			{% show_breadcrumb 0 "bootstrap3/menu/breadcrumb.html" %}
		</ol>
	</div>
</div>
{% endspaceless %}