{% load i18n menu_tags %}{% spaceless %}
{% if languages|length > 1 %}
<li uib-dropdown class="nav-item dropdown {{ dropdown_extra_class }}">
	<a uib-dropdown-toggle class="nav-link dropdown-toggle" role="button" aria-haspopup="true">
		<i class="fa fa-language"></i>&nbsp;{% trans "Language" %}
	</a>
	<div uib-dropdown-menu class="dropdown-menu" role="menu">
	{% for language in languages %}
		<a class="dropdown-item{% if current_language == language.0 %} active{% endif %}" href="{% page_language_url language.0 %}" title="{{ language.1 }}" role="menuitem">{{ language.1 }}</a>
	{% endfor %}
	</div>
</li>
{% endif %}{% endspaceless %}
