{% load menu_tags %}{% spaceless %}
<nav aria-label="breadcrumb" class="{{ breadcrumb_classes }}">
	<ol class="breadcrumb">
		{% show_breadcrumb 0 "bootstrap4/menu/breadcrumb.html" %}
	</ol>
</nav>
{% endspaceless %}